﻿Imports System.Windows.Forms.Design
Imports System.ComponentModel.Design
Imports System.ComponentModel

Public Class customTextBoxDesigner
    Inherits ControlDesigner

    Private _actionListCollection As DesignerActionListCollection

    Public Overrides ReadOnly Property ActionLists() As System.ComponentModel.Design.DesignerActionListCollection
        Get
            If _actionListCollection Is Nothing Then
                _actionListCollection = New DesignerActionListCollection()
                _actionListCollection.Add(New TextBoxActionList(Me.Control))
            End If

            Return _actionListCollection
        End Get
    End Property
End Class

Friend Class TextBoxActionList
    Inherits DesignerActionList

    Private txt As customTextBox
    Private designerActionSvc As DesignerActionUIService

    Public Sub New(ByVal component As IComponent)
        MyBase.New(component)

        txt = DirectCast(component, customTextBox)
        designerActionSvc = CType(GetService(GetType(DesignerActionUIService)), DesignerActionUIService)
    End Sub

#Region " Properties to display in the Smart-Tag panel "

    Public Property Text() As String
        Get
            Return txt.Text
        End Get
        Set(ByVal value As String)
            txt.Text = value
        End Set
    End Property

    Public Property Font() As Font
        Get
            Return txt.Font
        End Get
        Set(ByVal value As Font)
            txt.Font = value
        End Set
    End Property

    Public Property BackColor() As Color
        Get
            Return txt.BackColor
        End Get
        Set(ByVal value As Color)
            txt.BackColor = value
        End Set
    End Property

    Public Property MultiLine() As Boolean
        Get
            Return txt.Multiline
        End Get
        Set(ByVal value As Boolean)
            txt.Multiline = value
            designerActionSvc.Refresh(txt)
        End Set
    End Property

#End Region

#Region " Methods to display in the Smart-Tag panel "

    Public Sub OnClear()
        txt.Clear()
    End Sub

    Public Sub OnMakeSquare()
        If txt.Multiline Then
            If txt.Width >= txt.Height Then
                txt.Height = txt.Width
            Else
                txt.Width = txt.Height
            End If

            designerActionSvc.Refresh(txt)
        End If
    End Sub

    Public Sub OnDock()
        If txt.Dock = DockStyle.Fill Then
            txt.Dock = DockStyle.None
        Else
            txt.Dock = DockStyle.Fill
        End If

        designerActionSvc.Refresh(txt)
    End Sub

#End Region

    Public Overrides Function GetSortedActionItems() As System.ComponentModel.Design.DesignerActionItemCollection
        Dim str As String
        Dim items As New DesignerActionItemCollection

        If txt.Dock = DockStyle.Fill Then
            str = "Undock in parent container."
        Else
            str = "Dock in parent container."
        End If

        'Add a few Header Items (categories)
        items.Add(New DesignerActionHeaderItem("Category 1"))
        items.Add(New DesignerActionHeaderItem("Category 2"))

        'Add the properties
        items.Add(New DesignerActionPropertyItem("Text", "Text", "Category 1", "Gets or sets the Text of the customTextBox."))
        items.Add(New DesignerActionPropertyItem("Font", "Font", "Category 1", "Gets or sets the Font of the customTextBox."))
        items.Add(New DesignerActionPropertyItem("BackColor", "BackColor", "Category 1", "Gets or sets the BackColor of the customTextBox."))
        items.Add(New DesignerActionPropertyItem("MultiLine", "Multi-line", "Category 1", "Gets or sets the Multi-line property of the customTextBox."))

        'Add the methods
        items.Add(New DesignerActionMethodItem(Me, "OnClear", "Clear text", "Category 2", "Clears the text in the customTextBox."))
        If txt.Multiline Then
            items.Add(New DesignerActionMethodItem(Me, "OnMakeSquare", "Make a square", "Category 2", "Changes the width or height of the customTextBox to resemble a square."))
            items.Add(New DesignerActionMethodItem(Me, "OnDock", str, "Category 2", "Docks or undocks the customTextBox in the parent container."))
        End If

        'Return the ActionItemCollection
        Return items
    End Function
End Class